<?php

namespace Bixo\Schedule\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Bixo\Schedule\Forms\FollowUps as FollowUpsForm;
use Bixo\Schedule\Http\Requests\FollowUpsResourceRequest;
use Bixo\Schedule\Http\Resources\FollowUpsResource;
use Bixo\Schedule\Http\Resources\FollowUpsCollection;
use Bixo\Schedule\Models\FollowUps;
use Bixo\Schedule\Actions\FollowUpsAction;
use Bixo\Schedule\Actions\FollowUpsActions;


/**
 * Resource controller class for follow_ups.
 */
class FollowUpsResourceController extends BaseController
{

    /**
     * Initialize follow_ups resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = FollowUpsForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('bixo.schedule.modules'), 'schedule', guard_url('schedule'));
            return $next($request);
        });
    }

    /**
     * Display a list of follow_ups.
     *
     * @return Response
     */
    public function index(FollowUpsResourceRequest $request)
    {
        $request = $request->all();
        $page = FollowUpsActions::run('paginate', $request);

        $data = new FollowUpsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('schedule::follow_ups.names'))
            ->view('schedule::follow_ups.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display follow_ups.
     *
     * @param Request $request
     * @param Model   $follow_ups
     *
     * @return Response
     */
    public function show(FollowUpsResourceRequest $request, FollowUps $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new FollowUpsResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('schedule::follow_ups.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('schedule::follow_ups.show')
            ->output();
    }

    /**
     * Show the form for creating a new follow_ups.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(FollowUpsResourceRequest $request, FollowUps $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new FollowUpsResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('schedule::follow_ups.name'))
            ->view('schedule::follow_ups.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new follow_ups.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(FollowUpsResourceRequest $request, FollowUps $model)
    {
        try {
            $request = $request->all();
            $model = FollowUpsAction::run('store', $model, $request);
            $data = new FollowUpsResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('schedule::follow_ups.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('schedule/follow_ups/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/schedule/follow_ups'))
                ->redirect();
        }

    }

    /**
     * Show follow_ups for editing.
     *
     * @param Request $request
     * @param Model   $follow_ups
     *
     * @return Response
     */
    public function edit(FollowUpsResourceRequest $request, FollowUps $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new FollowUpsResource($model);
        // return view('schedule::follow_ups.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('schedule::follow_ups.name'))
            ->view('schedule::follow_ups.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the follow_ups.
     *
     * @param Request $request
     * @param Model   $follow_ups
     *
     * @return Response
     */
    public function update(FollowUpsResourceRequest $request, FollowUps $model)
    {
        try {
            $request = $request->all();
            $model = FollowUpsAction::run('update', $model, $request);
            $data = new FollowUpsResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('schedule::follow_ups.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('schedule/follow_ups/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('schedule/follow_ups/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the follow_ups.
     *
     * @param Model   $follow_ups
     *
     * @return Response
     */
    public function destroy(FollowUpsResourceRequest $request, FollowUps $model)
    {
        try {

            $request = $request->all();
            $model = FollowUpsAction::run('destroy', $model, $request);
            $data = new FollowUpsResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('schedule::follow_ups.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('schedule/follow_ups/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('schedule/follow_ups/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
